@@ -371,7 +371,11 @@ class ModTest(TestCase):
         # model_admin allows user to view just 2 objects that belong to her.
         response = self.client.get('/admin/test_app/reader/', follow = True)
         self.assertEquals(response.status_code, 200)
-        result_count = len(response.context[-1]['cl'].result_list)
+        try:
+            result_count = len(response.context[-1]['cl'].result_list)
+        except KeyError:
+            # In Django 1.4, cl is a member of response.context itself.
+            result_count = len(response.context['cl'].result_list)
         self.assertEquals(result_count, 2)
         # Now is the time to test monitor_queue. Same result expected.
         response = self.client.get(
